@@ -51,7 +51,7 @@ class OptimizerTest(chex.TestCase):
 
     @chex.all_variants(with_pmap=False)
     @parameterized.parameters(
-        [(5, 10), (10, 1), (10, 20)],
+        [(5, 10), (10, 2), (10, 20)],
     )
     def test_minimize_lbfgs(self, maxiter, maxcor):
         """Test if dot product between approximate inverse hessian and gradient is
@@ -60,12 +60,11 @@ class OptimizerTest(chex.TestCase):
 
         def regression_logprob(scale, coefs, preds, x):
             """Linear regression"""
-            logpdf = 0
-            logpdf += stats.expon.logpdf(scale, 0, 2)
-            logpdf += stats.norm.logpdf(coefs, 3 * jnp.ones(x.shape[-1]), 2)
+            scale_prior = stats.expon.logpdf(scale, 1, 1)
+            coefs_prior = stats.norm.logpdf(coefs, 0, 5)
             y = jnp.dot(x, coefs)
-            logpdf += stats.norm.logpdf(preds, y, scale)
-            return jnp.sum(logpdf)
+            logpdf = stats.norm.logpdf(preds, y, scale)
+            return sum(x.sum() for x in [scale_prior, coefs_prior, logpdf])
 
         def regression_model(key):
             init_key0, init_key1 = jax.random.split(key, 2)
