@@ -70,12 +70,12 @@ class LinearRegressionTest(chex.TestCase):
 
     def regression_logprob(self, scale, coefs, preds, x):
         """Linear regression"""
-        logpdf = 0
-        logpdf += stats.expon.logpdf(scale, 1, 1)
-        logpdf += stats.norm.logpdf(coefs, 3 * jnp.ones(x.shape[-1]), 2)
+        scale_prior = stats.expon.logpdf(scale, 1, 1)
+        coefs_prior = stats.norm.logpdf(coefs, 0, 5)
         y = jnp.dot(x, coefs)
-        logpdf += stats.norm.logpdf(preds, y, scale)
-        return jnp.sum(logpdf)
+        logpdf = stats.norm.logpdf(preds, y, scale)
+        # reduce sum otherwise broacasting will make the logprob biased.
+        return sum(x.sum() for x in [scale_prior, coefs_prior, logpdf])
 
     @parameterized.parameters(itertools.product(regression_test_cases, [True, False]))
     def test_window_adaptation(self, case, is_mass_matrix_diagonal):
@@ -177,6 +177,43 @@ class LinearRegressionTest(chex.TestCase):
         np.testing.assert_allclose(np.mean(scale_samples), 1.0, atol=1e-1)
         np.testing.assert_allclose(np.mean(coefs_samples), 3.0, atol=1e-1)
 
+    def test_meads(self):
+        """Test the MEADS adaptation w/ GHMC kernel."""
+        rng_key, init_key0, init_key1 = jax.random.split(self.key, 3)
+        x_data = jax.random.normal(init_key0, shape=(1000, 1))
+        y_data = 3 * x_data + jax.random.normal(init_key1, shape=x_data.shape)
+
+        logposterior_fn_ = functools.partial(
+            self.regression_logprob, x=x_data, preds=y_data
+        )
+        logposterior_fn = lambda x: logposterior_fn_(**x)
+
+        init_key, warmup_key, inference_key = jax.random.split(rng_key, 3)
+
+        warmup = blackjax.meads(
+            logposterior_fn,
+            num_chain=128,
+            num_steps=100,
+        )
+        scale_key, coefs_key = jax.random.split(init_key, 2)
+        scales = 1.0 + jax.random.normal(scale_key, (128,))
+        coefs = 3.0 + jax.random.normal(coefs_key, (128,))
+        initial_positions = {"scale": scales, "coefs": coefs}
+        chains_state, kernel, _ = warmup.run(
+            warmup_key,
+            initial_positions,
+        )
+
+        states = jax.vmap(
+            lambda state: inference_loop(kernel, 100, inference_key, state)
+        )(chains_state.states)
+
+        coefs_samples = states.position["coefs"]
+        scale_samples = states.position["scale"]
+
+        np.testing.assert_allclose(np.mean(scale_samples), 1.0, atol=1e-1)
+        np.testing.assert_allclose(np.mean(coefs_samples), 3.0, atol=1e-1)
+
 
 class SGMCMCTest(chex.TestCase):
     """Test sampling of a linear regression model."""
@@ -192,7 +229,11 @@ class SGMCMCTest(chex.TestCase):
         w = x - position
         return -0.5 * jnp.dot(w, w)
 
-    def test_linear_regression_sgld(self):
+    def constant_step_size(_):
+        return 1e-3
+
+    @parameterized.parameters((1e-3, False), (constant_step_size, False), (1, True))
+    def test_linear_regression_sgld(self, learning_rate, error_expected):
         """Test the HMC kernel and the Stan warmup."""
         import blackjax.sgmcmc.gradients
 
@@ -201,12 +242,15 @@ class SGMCMCTest(chex.TestCase):
         data_size = 1000
         X_data = jax.random.normal(data_key, shape=(data_size, 5))
 
-        schedule_fn = lambda _: 1e-3
         grad_fn = blackjax.sgmcmc.gradients.grad_estimator(
             self.logprior_fn, self.loglikelihood_fn, data_size
         )
-        sgld = blackjax.sgld(grad_fn, schedule_fn)
 
+        if error_expected:
+            self.assertRaises(TypeError, blackjax.sgld(grad_fn, learning_rate))
+            return
+
+        sgld = blackjax.sgld(grad_fn, learning_rate)
         init_position = 1.0
         data_batch = X_data[:100, :]
         init_state = sgld.init(init_position, data_batch)
@@ -215,7 +259,8 @@ class SGMCMCTest(chex.TestCase):
         data_batch = X_data[100:200, :]
         _ = sgld.step(rng_key, init_state, data_batch)
 
-    def test_linear_regression_sghmc(self):
+    @parameterized.parameters((1e-3, False), (constant_step_size, False), (1, True))
+    def test_linear_regression_sghmc(self, learning_rate, error_expected):
         """Test the HMC kernel and the Stan warmup."""
         import blackjax.sgmcmc.gradients
 
@@ -224,11 +269,15 @@ class SGMCMCTest(chex.TestCase):
         data_size = 1000
         X_data = jax.random.normal(data_key, shape=(data_size, 5))
 
-        schedule_fn = lambda _: 1e-3
         grad_fn = blackjax.sgmcmc.gradients.grad_estimator(
             self.logprior_fn, self.loglikelihood_fn, data_size
         )
-        sghmc = blackjax.sghmc(grad_fn, schedule_fn, 10)
+
+        if error_expected:
+            self.assertRaises(TypeError, blackjax.sgld(grad_fn, learning_rate))
+            return
+
+        sghmc = blackjax.sghmc(grad_fn, learning_rate, 10)
 
         init_position = 1.0
         data_batch = X_data[:100, :]
@@ -329,6 +378,17 @@ normal_test_cases = [
         "num_sampling_steps": 50_000,
         "burnin": 5_000,
     },
+    {
+        "algorithm": blackjax.ghmc,
+        "initial_position": jnp.array(1.0),
+        "parameters": {
+            "step_size": jnp.array(1.0),
+            "alpha": 0.8,
+            "delta": 2.0,
+        },
+        "num_sampling_steps": 6000,
+        "burnin": 1_000,
+    },
 ]
 
 
@@ -353,7 +413,10 @@ class UnivariateNormalTest(chex.TestCase):
         algo = algorithm(self.normal_logprob, **parameters)
         if algorithm == blackjax.elliptical_slice:
             algo = algorithm(lambda _: 1.0, **parameters)
-        initial_state = algo.init(initial_position)
+        if algorithm == blackjax.ghmc:
+            initial_state = algo.init(initial_position, self.key)
+        else:
+            initial_state = algo.init(initial_position)
 
         kernel = algo.step
         states = self.variant(
